summaryrefslogtreecommitdiff
path: root/src/lib/dcp_video_frame.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2013-01-23 20:06:37 +0000
committerCarl Hetherington <cth@carlh.net>2013-01-23 20:06:37 +0000
commitd1b20374b1bd02b2929c9c3080c006874b525ef5 (patch)
treec35e9150caf5c6cdea75d4b223cb5bbd0b28032a /src/lib/dcp_video_frame.h
parent125e52fbb84ab9a28f3cc9cf8a74dc8a568d4049 (diff)
Remove multi-reel, for now, and sort out Size vs libdcp::Size.
Diffstat (limited to 'src/lib/dcp_video_frame.h')
-rw-r--r--src/lib/dcp_video_frame.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/lib/dcp_video_frame.h b/src/lib/dcp_video_frame.h
index 134720da8..c0eff3f35 100644
--- a/src/lib/dcp_video_frame.h
+++ b/src/lib/dcp_video_frame.h
@@ -40,7 +40,7 @@ class EncodedData
{
public:
/** @param d Data (will not be freed by this class, but may be by subclasses)
* @param s Size of data, in bytes.
*/
EncodedData (uint8_t* d, int s)
: _data (d)
@@ -76,7 +76,7 @@ class LocallyEncodedData : public EncodedData
{
public:
/** @param d Data (which will not be freed by this class)
* @param s Size of data, in bytes.
*/
LocallyEncodedData (uint8_t* d, int s)
: EncodedData (d, s)
@@ -107,7 +107,7 @@ class DCPVideoFrame
{
public:
DCPVideoFrame (
- boost::shared_ptr<const Image>, boost::shared_ptr<Subtitle>, Size,
+ boost::shared_ptr<const Image>, boost::shared_ptr<Subtitle>, libdcp::Size,
int, int, float, Scaler const *, SourceFrame, float, std::string, int, int, Log *
);
@@ -125,7 +125,7 @@ private:
boost::shared_ptr<const Image> _input; ///< the input image
boost::shared_ptr<Subtitle> _subtitle; ///< any subtitle that should be on the image
- Size _out_size; ///< the required size of the output, in pixels
+ libdcp::Size _out_size; ///< the required size of the output, in pixels
int _padding;
int _subtitle_offset;
float _subtitle_scale;
@@ -40,7 +40,7 @@ class EncodedData
public:
/** @param d Data (will not be freed by this class, but may be by subclasses)
- * @param s Size of data, in bytes.
+ * @param s libdcp::Size of data, in bytes.
*/
EncodedData (uint8_t* d, int s)
@@ -76,7 +76,7 @@ class LocallyEncodedData : public EncodedData
public:
/** @param d Data (which will not be freed by this class)
- * @param s Size of data, in bytes.
+ * @param s libdcp::Size of data, in bytes.
*/
LocallyEncodedData (uint8_t* d, int s)